<?php
/**
 * Wood Master: Customizer
 *
 * @subpackage Wood Master
 * @since 1.0
 */

use WPTRT\Customize\Section\Wood_Master_Button;

add_action( 'customize_register', function( $manager ) {

	$manager->register_section_type( Wood_Master_Button::class );

	$manager->add_section(
		new Wood_Master_Button( $manager, 'wood_master_pro', [
			'title'      => __( 'Wood Master Pro', 'wood-master' ),
			'priority'    => 0,
			'button_text' => __( 'Go Pro', 'wood-master' ),
			'button_url'  => esc_url( 'https://www.luzuk.com/product/wood-wordpress-theme/', 'wood-master')
		] )
	);

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

	$version = wp_get_theme()->get( 'Version' );

	wp_enqueue_script(
		'wood-master-customize-section-button',
		get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
		[ 'customize-controls' ],
		$version,
		true
	);

	wp_enqueue_style(
		'wood-master-customize-section-button',
		get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
		[ 'customize-controls' ],
 		$version
	);

} );

function wood_master_customize_register( $wp_customize ) {

	$wp_customize->add_setting('wood_master_logo_margin',array(
		'sanitize_callback'	=> 'esc_html'
	));
	$wp_customize->add_control('wood_master_logo_margin',array(
		'label' => __('Logo Margin','wood-master'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting('wood_master_logo_top_margin',array(
		'default' => '',
		'sanitize_callback'	=> 'wood_master_sanitize_float'
	));
	$wp_customize->add_control('wood_master_logo_top_margin',array(
		'type' => 'number',
		'description' => __('Top','wood-master'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('wood_master_logo_bottom_margin',array(
		'default' => '',
		'sanitize_callback'	=> 'wood_master_sanitize_float'
	));
	$wp_customize->add_control('wood_master_logo_bottom_margin',array(
		'type' => 'number',
		'description' => __('Bottom','wood-master'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('wood_master_logo_left_margin',array(
		'default' => '',
		'sanitize_callback'	=> 'wood_master_sanitize_float'
	));
	$wp_customize->add_control('wood_master_logo_left_margin',array(
		'type' => 'number',
		'description' => __('Left','wood-master'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('wood_master_logo_right_margin',array(
		'default' => '',
		'sanitize_callback'	=> 'wood_master_sanitize_float'
 	));
 	$wp_customize->add_control('wood_master_logo_right_margin',array(
		'type' => 'number',
		'description' => __('Right','wood-master'),
		'section' => 'title_tagline',
    ));

	$wp_customize->add_setting('wood_master_show_site_title',array(
		'default' => true,
		'sanitize_callback'	=> 'wood_master_sanitize_checkbox'
	));
	$wp_customize->add_control('wood_master_show_site_title',array(
		'type' => 'checkbox',
		'label' => __('Show / Hide Site Title','wood-master'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting('wood_master_show_tagline',array(
		'default' => true,
		'sanitize_callback'	=> 'wood_master_sanitize_checkbox'
	));
	$wp_customize->add_control('wood_master_show_tagline',array(
		'type' => 'checkbox',
		'label' => __('Show / Hide Site Tagline','wood-master'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_panel( 'wood_master_panel_id', array(
		'priority' => 10,
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => __( 'Theme Settings', 'wood-master' ),
		'description' => __( 'Description of what this panel does.', 'wood-master' ),
	) );

	$wp_customize->add_section( 'wood_master_theme_options_section', array(
    	'title'      => __( 'General Settings', 'wood-master' ),
		'priority'   => 30,
		'panel' => 'wood_master_panel_id'
	) );

	$wp_customize->add_setting('wood_master_theme_options',array(
		'default' => 'Right Sidebar',
		'sanitize_callback' => 'wood_master_sanitize_choices'
	));
	$wp_customize->add_control('wood_master_theme_options',array(
		'type' => 'select',
		'label' => __('Blog Page Sidebar Layout','wood-master'),
		'section' => 'wood_master_theme_options_section',
		'choices' => array(
		   'Left Sidebar' => __('Left Sidebar','wood-master'),
		   'Right Sidebar' => __('Right Sidebar','wood-master'),
		   'One Column' => __('One Column','wood-master'),
		   'Grid Layout' => __('Grid Layout','wood-master')
		),
	));

	$wp_customize->add_setting('wood_master_single_post_sidebar',array(
		'default' => 'Right Sidebar',
		'sanitize_callback' => 'wood_master_sanitize_choices'
	));
	$wp_customize->add_control('wood_master_single_post_sidebar',array(
        'type' => 'select',
        'label' => __('Single Post Sidebar Layout','wood-master'),
        'section' => 'wood_master_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','wood-master'),
            'Right Sidebar' => __('Right Sidebar','wood-master'),
            'One Column' => __('One Column','wood-master')
        ),
	));

	$wp_customize->add_setting('wood_master_page_sidebar',array(
		'default' => 'One Column',
		'sanitize_callback' => 'wood_master_sanitize_choices'
	));
	$wp_customize->add_control('wood_master_page_sidebar',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','wood-master'),
        'section' => 'wood_master_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','wood-master'),
            'Right Sidebar' => __('Right Sidebar','wood-master'),
            'One Column' => __('One Column','wood-master')
        ),
	));

	$wp_customize->add_setting('wood_master_archive_page_sidebar',array(
		'default' => 'Right Sidebar',
		'sanitize_callback' => 'wood_master_sanitize_choices'
	));
	$wp_customize->add_control('wood_master_archive_page_sidebar',array(
        'type' => 'select',
        'label' => __('Archive & Search Page Sidebar Layout','wood-master'),
        'section' => 'wood_master_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','wood-master'),
            'Right Sidebar' => __('Right Sidebar','wood-master'),
            'One Column' => __('One Column','wood-master'),
            'Grid Layout' => __('Grid Layout','wood-master')
        ),
	));

	//Bottom Header
	$wp_customize->add_section( 'wood_master_header_section' , array(
    	'title'    => __( 'Header', 'wood-master' ),
		'priority' => null,
		'panel' => 'wood_master_panel_id'
	) );

	$wp_customize->add_setting('wood_master_topheader_phone_no',array(
    	'default' => '',
    	'sanitize_callback' => 'wood_master_sanitize_phone_number'
	));
	$wp_customize->add_control('wood_master_topheader_phone_no',array(
   	'type' => 'text',
   	'label' => __('Add Phone Number','wood-master'),
   	'section' => 'wood_master_header_section',
	));

	$wp_customize->add_setting('wood_master_topheader_facebook_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('wood_master_topheader_facebook_url',array(
   	'type' => 'url',
   	'label' => __('Add Facebook URL','wood-master'),
   	'section' => 'wood_master_header_section',
	));

	$wp_customize->add_setting('wood_master_topheader_twitter_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('wood_master_topheader_twitter_url',array(
   	'type' => 'url',
   	'label' => __('Add Twitter URL','wood-master'),
   	'section' => 'wood_master_header_section',
	));

	$wp_customize->add_setting('wood_master_topheader_instagram_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('wood_master_topheader_instagram_url',array(
   	'type' => 'url',
   	'label' => __('Add Instagram URL','wood-master'),
   	'section' => 'wood_master_header_section',
	));

	$wp_customize->add_setting('wood_master_topheader_linkedin_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('wood_master_topheader_linkedin_url',array(
   	'type' => 'url',
   	'label' => __('Add Linkedin URL','wood-master'),
   	'section' => 'wood_master_header_section',
	));

	//home page slider
	$wp_customize->add_section( 'wood_master_slider_section' , array(
    	'title'    => __( 'Slider Settings', 'wood-master' ),
		'priority' => null,
		'panel' => 'wood_master_panel_id'
	) );

	$wp_customize->add_setting('wood_master_slider_hide_show',array(
    	'default' => false,
    	'sanitize_callback'	=> 'wood_master_sanitize_checkbox'
	));
	$wp_customize->add_control('wood_master_slider_hide_show',array(
   	'type' => 'checkbox',
   	'label' => __('Show / Hide Slider','wood-master'),
   	'section' => 'wood_master_slider_section',
	));

	for ( $count = 1; $count <= 4; $count++ ) {
		$wp_customize->add_setting( 'wood_master_slider' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'wood_master_sanitize_dropdown_pages'
		));
		$wp_customize->add_control( 'wood_master_slider' . $count, array(
			'label' => __('Select Slider Image Page', 'wood-master' ),
			'description' => __('Image Size (1600px x 600px)', 'wood-master' ),
			'section' => 'wood_master_slider_section',
			'type' => 'dropdown-pages'
		));
	}

	//Service Section
	$wp_customize->add_section('wood_master_service_section',array(
		'title'	=> __('Service Section','wood-master'),
		'description'=> __('This section will appear below the slider.','wood-master'),
		'panel' => 'wood_master_panel_id',
	));

	$wp_customize->add_setting('wood_master_section_title',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wood_master_section_title',array(
   	'type' => 'text',
   	'label' => __('Section Title','wood-master'),
   	'section' => 'wood_master_service_section',
	));

	$wp_customize->add_setting('wood_master_section_text',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wood_master_section_text',array(
   	'type' => 'text',
   	'label' => __('Section Text','wood-master'),
   	'section' => 'wood_master_service_section',
	));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_pst[]= 'select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_pst[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('wood_master_service_category',array(
		'default' => 'select',
		'sanitize_callback' => 'wood_master_sanitize_choices',
	));
	$wp_customize->add_control('wood_master_service_category',array(
		'type'    => 'select',
		'choices' => $cat_pst,
		'label' => __('Select Category to display Post','wood-master'),
		'section' => 'wood_master_service_section',
	));

	//Footer
    $wp_customize->add_section( 'wood_master_footer', array(
    	'title'  => __( 'Footer Text', 'wood-master' ),
		'priority' => null,
		'panel' => 'wood_master_panel_id'
	) );

	$wp_customize->add_setting('wood_master_show_back_totop',array(
       'default' => true,
       'sanitize_callback'	=> 'wood_master_sanitize_checkbox'
    ));
    $wp_customize->add_control('wood_master_show_back_totop',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Back to Top','wood-master'),
       'section' => 'wood_master_footer'
    ));

    $wp_customize->add_setting('wood_master_footer_copy',array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('wood_master_footer_copy',array(
		'label'	=> __('Footer Text','wood-master'),
		'section' => 'wood_master_footer',
		'setting' => 'wood_master_footer_copy',
		'type' => 'text'
	));

	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'wood_master_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'wood_master_customize_partial_blogdescription',
	) );

	//front page
	$num_sections = apply_filters( 'wood_master_front_page_sections', 4 );

	// Create a setting and control for each of the sections available in the theme.
	for ( $i = 1; $i < ( 1 + $num_sections ); $i++ ) {
		$wp_customize->add_setting( 'panel_' . $i, array(
			'default'           => false,
			'sanitize_callback' => 'wood_master_sanitize_dropdown_pages',
			'transport'         => 'postMessage',
		) );

		$wp_customize->add_control( 'panel_' . $i, array(
			/* translators: %d is the front page section number */
			'label'          => sprintf( __( 'Front Page Section %d Content', 'wood-master' ), $i ),
			'description'    => ( 1 !== $i ? '' : __( 'Select pages to feature in each area from the dropdowns. Add an image to a section by setting a featured image in the page editor. Empty sections will not be displayed.', 'wood-master' ) ),
			'section'        => 'theme_options',
			'type'           => 'dropdown-pages',
			'allow_addition' => true,
			'active_callback' => 'wood_master_is_static_front_page',
		) );

		$wp_customize->selective_refresh->add_partial( 'panel_' . $i, array(
			'selector'            => '#panel' . $i,
			'render_callback'     => 'wood_master_front_page_section',
			'container_inclusive' => true,
		) );
	}
}
add_action( 'customize_register', 'wood_master_customize_register' );

function wood_master_customize_partial_blogname() {
	bloginfo( 'name' );
}

function wood_master_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

function wood_master_is_static_front_page() {
	return ( is_front_page() && ! is_home() );
}

function wood_master_is_view_with_layout_option() {
	// This option is available on all pages. It's also available on archives when there isn't a sidebar.
	return ( is_page() || ( is_archive() && ! is_active_sidebar( 'sidebar-1' ) ) );
}